<?php

require_once( $_SERVER['DOCUMENT_ROOT'] . '/classes/clutch-class.php' );

class db_handler extends clutch_class {
	
	/**
	 * Helper function for establishing a MySQLi connection
	 *
	 * @return bool|die true if successful, this->dieWithError if not
	 **/
	public function make_connection() {
		
		$connection = new mysqli( "localhost", CLUTCH_DATABASE_USER, CLUTCH_DATABASE_PASSWORD, CLUTCH_DATABASE );
		
		// . If connection error
		if ( @$connection->connect_error ) {
			$this->log_error(
				sprintf(
					'Connection failed. MySQL said: %s',
					$connection->connect_error()
				)
			);
		} else {
			$this->connection = $connection;
			return true;
		}
	}
	
	/**
	 * Helper function to close a MySQLi connection
	 **/
	private function close_connection() {
		if( $this->connection ) {
			$this->connection->close();
			$this->connection = false;
		}
	}
	
	/**
	 * Helper function to escape input strings
	 *
	 * @return string $escaped
	 **/
	public function escape_string( $string ) {
		
		$this->make_connection();
		
		$escaped = $this->connection->escape_string( $string );
		
		$this->close_connection();
		
		return $escaped;
	}
	
	/**
	 * Performs a MySQLi query with given string $sql
	 *
	 * @return array|int|bool:
	 * 		array MySQLi results if successful query and $return_rows !== false
	 * 		int $insert_id if $return_rows === 'id'
	 * 		false if no results found
	 **/
	public function run_query( $sql, $return_rows ) {
		
		
		$this->make_connection();
		
		$result = $this->connection->query( $sql );
		
		if( ! @$result ) {
			
			$this->log_error( "Query failed. MySQL said: " . $this->connection->error );
			
			$this->close_connection();
			return false;
		}
		
		if( $return_rows ) {
			
			if( 1 === $return_rows ) {
				while ( $row = $result->fetch_array( MYSQLI_ASSOC ) ) {
					$this->close_connection();
					return $row;
				}
			}
			else if ( 'id' === $return_rows ) {
				$id = $this->connection->insert_id;
				$this->close_connection();
				return $id;
			}
			else {
				$all_results = $result->fetch_all( MYSQLI_ASSOC );
				$this->close_connection();
				return $all_results;
			}
		}
		else {
			$this->close_connection();
			return true;
		}
	}
	
}